@@ -91,11 +91,8 @@ KisPaintOpPresetSP KisPaintOpPreset::clone() const
 void KisPaintOpPreset::setPresetDirty(bool value)
 {
     m_d->dirtyPreset = value;
-
-    if (m_d->updateProxy && m_d->dirtyPreset != value) {
-        m_d->updateProxy->notifySettingsChanged();
-    }
 }
+
 bool KisPaintOpPreset::isPresetDirty() const
 {
     return m_d->dirtyPreset;
@@ -391,3 +388,18 @@ QList<KisUniformPaintOpPropertySP> KisPaintOpPreset::uniformProperties()
 {
     return m_d->settings->uniformProperties(m_d->settings);
 }
+
+KisPaintOpPreset::UpdatedPostponer::UpdatedPostponer(KisPaintOpPreset *preset)
+    : m_updateProxy(preset->updateProxyNoCreate())
+{
+    if (m_updateProxy) {
+        m_updateProxy->postponeSettingsChanges();
+    }
+}
+
+KisPaintOpPreset::UpdatedPostponer::~UpdatedPostponer()
+{
+    if (m_updateProxy) {
+        m_updateProxy->unpostponeSettingsChanges();
+    }
+}
