@@ -92,6 +92,16 @@ protected:
     virtual void writeMergeData(KisPainter *painter, KisPaintDeviceSP src);
     void lockTemporaryTargetForWrite() const;
 
+    struct WriteLockableWrapper {
+        WriteLockableWrapper(KisIndirectPaintingSupport *lock) : m_lock(lock) {}
+        void lock() { m_lock->lockTemporaryTargetForWrite(); }
+        void unlock() { m_lock->unlockTemporaryTarget(); }
+
+    private:
+        KisIndirectPaintingSupport *m_lock;
+    };
+
+
     QString temporaryCompositeOp() const;
     void releaseResources();
 
