@@ -76,10 +76,10 @@ public:
     virtual ~KisLayer();
 
     /// returns the image's colorSpace or null, if there is no image
-    virtual const KoColorSpace * colorSpace() const;
+    virtual const KoColorSpace * colorSpace() const override;
 
     /// returns the layer's composite op for the colorspace of the layer's parent.
-    const KoCompositeOp * compositeOp() const;
+    const KoCompositeOp * compositeOp() const override;
 
     KisPSDLayerStyleSP layerStyle() const;
     void setLayerStyle(KisPSDLayerStyleSP layerStyle);
@@ -87,7 +87,7 @@ public:
     /**
      * \see a comment in KisNode::projectionPlane()
      */
-    virtual KisAbstractProjectionPlaneSP projectionPlane() const;
+    virtual KisAbstractProjectionPlaneSP projectionPlane() const override;
 
     /**
      * The projection plane representing the layer itself without any
@@ -105,7 +105,7 @@ public:
      * Return the fully rendered representation of this layer: its
      * data and its effect masks
      */
-    KisPaintDeviceSP projection() const;
+    KisPaintDeviceSP projection() const override;
 
     /**
      * Return the layer data before the effect masks have had their go
@@ -125,8 +125,8 @@ public:
      */
     virtual KisSelectionSP selection() const;
 
-    virtual KisBaseNode::PropertyList sectionModelProperties() const;
-    virtual void setSectionModelProperties(const KisBaseNode::PropertyList &properties);
+    virtual KisBaseNode::PropertyList sectionModelProperties() const override;
+    virtual void setSectionModelProperties(const KisBaseNode::PropertyList &properties) override;
 
     /**
      * set/unset the channel flag for the alpha channel of this layer
@@ -225,25 +225,25 @@ public:
     void updateClones(const QRect &rect);
 
 public:
-    qint32 x() const;
-    qint32 y() const;
+    qint32 x() const override;
+    qint32 y() const override;
 
-    void setX(qint32 x);
-    void setY(qint32 y);
+    void setX(qint32 x) override;
+    void setY(qint32 y) override;
 
     /**
      * Returns an approximation of where the bounds
      * of actual data of this layer are
      */
-    QRect extent() const;
+    QRect extent() const override;
 
     /**
      * Returns the exact bounds of where the actual data
      * of this layer resides
      */
-    QRect exactBounds() const;
+    QRect exactBounds() const override;
 
-    QImage createThumbnail(qint32 w, qint32 h);
+    QImage createThumbnail(qint32 w, qint32 h) override;
 
 public:
     /**
@@ -268,7 +268,7 @@ public:
 
 protected:
     // override from KisNode
-    QRect changeRect(const QRect &rect, PositionToFilthy pos = N_FILTHY) const;
+    QRect changeRect(const QRect &rect, PositionToFilthy pos = N_FILTHY) const override;
 
 protected:
 
