@@ -61,7 +61,7 @@ public:
         CurrentGeneratorConfiguration,
         CurrentCompositeOp,
         CurrentEffectiveCompositeOp,
-        LodAvailability,
+        LodAvailability, ///<-user choice
         EraserMode,
         MirrorHorizontal,
         MirrorVertical,
@@ -78,7 +78,7 @@ public:
         DisablePressure,
         PreviousPaintOpPreset,
         EffectiveZoom, ///<-Used only by painting tools for non-displaying purposes
-        PresetAllowsLod,
+        PresetAllowsLod, ///<-combination of the user choice and thechnical abilities of the preset
         SelectionAction,
         SelectionMode
     };
