@@ -36,8 +36,8 @@ public:
 
     QPainterPath brushOutline(const KisPaintInformation &info, OutlineMode mode);
 
-    void setPaintOpSize(qreal value) Q_DECL_OVERRIDE;
-    qreal paintOpSize() const Q_DECL_OVERRIDE;
+    void setPaintOpSize(qreal value) override;
+    qreal paintOpSize() const override;
 
     bool paintIncremental();
     bool isAirbrushing() const;
